## Release 0.5.0
* support rgb dtypes
* change default dpi to 200
* make iTerm2's imgcat the default (instead of libsixel-python which does not work so well)

## Release 0.4.4
* udpate plotter for nibabel 5.0


